@@ -11,7 +11,7 @@ class BasicPeg(CompoundOrder):
     symbol: str
     side: str
     quantity: int
-    timezone: str = "UTC"
+    timezone: str = "local"
 
     def __init__(self, **data) -> None:
         super().__init__(**data)
@@ -91,7 +91,8 @@ class PegExisting(BaseModel):
     duration: int = 60
     peg_every: int = 10
     done: bool = False
-    lock: Optional[OrderLock] = None
+    order_args: Optional[Dict[str, str]] = None
+    modify_args: Optional[Dict[str, str]] = None
     lock_duration: int = 2
     _next_peg: Optional[pendulum.DateTime] = None
     _num_pegs: int = 0
@@ -108,8 +109,10 @@ class PegExisting(BaseModel):
         self._expire_at = pendulum.now(tz=self.timezone).add(seconds=self.duration)
         self._next_peg = pendulum.now(tz=self.timezone).add(seconds=self.peg_every)
         self.order.order_type = "LIMIT"
-        if self.lock is None:
-            self.lock = OrderLock()
+        if self.order_args is None:
+            self.order_args = {}
+        if self.modify_args is None:
+            self.modify_args = {}
 
     @validator("order")
     def order_should_be_pending(cls, v):
@@ -129,42 +132,38 @@ class PegExisting(BaseModel):
     def num_pegs(self) -> int:
         return self._num_pegs
 
-    def execute(self, **order_args):
-        self.order.execute(broker=self.broker)
+    def execute(self) -> None:
+        self.order.execute(broker=self.broker, **self.order_args)
 
-    def _mark_done(self) -> bool:
+    def _mark_done(self) -> None:
         """
         Mark whether the order is done
         """
-        if self.order.is_complete:
+        if self.order.is_done:
             self.done = True
-        elif not (self.order.is_pending):
-            self.done = True
-        return self.done
 
-    def run(self, ltp: float):
+    def run(self, ltp: float) -> None:
         if self.done:
             logging.warning("Order already done")
             return
 
+        self._mark_done()
         order = self.order
         now = pendulum.now(self.timezone)
         if order.is_pending:
             if now > self._expire_at:
                 if self.order.convert_to_market_after_expiry:
-                    if self.lock.can_modify:
-                        order.modify(broker=self.broker, order_type="MARKET")
-                        self.lock.modify(self.lock_duration)
+                    order.modify(
+                        broker=self.broker, order_type="MARKET", **self.modify_args
+                    )
+                    order.add_lock(1, self.lock_duration)
                 else:
-                    if self.lock.can_cancel:
-                        order.cancel(self.broker)
-                        self.lock.cancel(self.lock_duration)
+                    order.cancel(self.broker)
+                    order.add_lock(2, self.lock_duration)
             elif now > self.next_peg:
                 self._next_peg = now.add(seconds=self.peg_every)
-                if self.lock.can_modify:
-                    order.modify(broker=self.broker, price=ltp)
-                    self.lock.modify(self.lock_duration)
-        self._mark_done()
+                order.modify(broker=self.broker, price=ltp, **self.modify_args)
+                order.add_lock(1, self.lock_duration)
 
 
 class PegSequential(BaseModel):
@@ -179,7 +178,11 @@ class PegSequential(BaseModel):
     duration: int = 12
     peg_every: int = 4
     lock_duration: int = 2
+    order_args: Optional[Dict[str, str]] = None
+    modify_args: Optional[Dict[str, str]] = None
     done: bool = False
+    modify_args: Optional[Dict[str, str]] = None
+    skip_subsequent_if_failed = False
     _order: Optional[PegExisting] = None
     _start_time: Optional[pendulum.DateTime] = None
 
@@ -188,6 +191,10 @@ class PegSequential(BaseModel):
 
     def __init__(self, **data) -> None:
         super().__init__(**data)
+        if self.order_args is None:
+            self.order_args = {}
+        if self.modify_args is None:
+            self.modify_args = {}
         # Validate whether orders could be pegged
         for order in self.orders:
             peg = PegExisting(
@@ -196,6 +203,8 @@ class PegSequential(BaseModel):
                 duration=self.duration,
                 peg_every=self.peg_every,
                 lock_duration=self.lock_duration,
+                order_args=self.order_args,
+                modify_args=self.modify_args,
             )
         self._start_time = pendulum.now(tz=self.timezone)
 
@@ -254,6 +263,8 @@ class PegSequential(BaseModel):
                     duration=self.duration,
                     peg_every=self.peg_every,
                     lock_duration=self.lock_duration,
+                    order_args=self.order_args,
+                    modify_args=self.modify_args,
                 )
         return None
 
@@ -262,26 +273,71 @@ class PegSequential(BaseModel):
         Set the current order for pegging
         Note
         ----
-        1) Set the current order only when a existing peg
+        1) Set the current order only when an existing peg
         order is complete or there is no peg order
         """
         if self.order is None:
             self._order = self.get_current_order()
-        elif self.order.order.is_complete:
+        elif self.order.order.is_done:
             self._order = self.get_current_order()
         return self.order
 
-    def execute_all(self):
+    def execute_all(self) -> None:
         # Execute all pending orders
         for order in self.orders:
-            order.execute(broker=self.broker)
+            order.execute(broker=self.broker, **self.order_args)
 
-    def cancel_all(self):
+    def cancel_all(self) -> None:
         # Cancel all pending orders
         for order in self.orders:
             order.cancel(broker=self.broker)
 
-    def run(self, ltp: Dict[str, float]):
+    def _process_order_after_expiry(self, order: Order) -> None:
+        """
+        Process an order after expiry based on the given flags
+        """
+        if not order.order_id:
+            order.status = "CANCELED"
+            return
+        if order.cancel_after_expiry:
+            order.cancel(broker=self.broker)
+        elif order.convert_to_market_after_expiry:
+            order.price = 0
+            order.order_type = "MARKET"
+            order.modify(broker=self.broker)
+
+    def run_after_expiry(self) -> None:
+        """
+        Run this function after the overall peg time has expired.
+        This function could be overriden to match customized functionality
+        """
+        if self.done:
+            return
+        for order in self.orders:
+            if order.is_pending:
+                self._process_order_after_expiry(order)
+
+    def _mark_subsequent_orders_as_canceled(self) -> None:
+        """
+        Mark all subsequent orders as canceled if the
+        existing order status is canceled or rejected
+        """
+        index = 0
+        flag = False
+        for i, order in enumerate(self.orders):
+            if order.status in ("CANCELED", "CANCELLED", "REJECTED"):
+                index = i
+                flag = True
+                break
+        if flag and (index < len(self.orders) - 1):
+            for i in range(index + 1, len(self.orders)):
+                self.orders[i].status = "CANCELED"
+
+    def run(self, ltp: Dict[str, float]) -> None:
+        if self.done:
+            return
+        if self.skip_subsequent_if_failed:
+            self._mark_subsequent_orders_as_canceled()
         self.set_current_order()
         peg = self.order
         # Run only when there is an order
@@ -293,5 +349,7 @@ class PegSequential(BaseModel):
             last_price = ltp.get(symbol, 0)
             peg.run(ltp=last_price)
 
-    def _mark_done(self):
-        pass
+        self._mark_done()
+
+    def _mark_done(self) -> None:
+        self.done = all([order.is_done for order in self.orders])
